@@ -203,7 +203,7 @@ QPair <int, int> kpToolWidgetBase::defaultSelectedRowAndCol () const
 
     if (!objectName ().isEmpty ())
     {
-        KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupTools);
+        KConfigGroup cfg (KSharedConfig::openConfig (), QStringLiteral(kpSettingsGroupTools));
 
         row = cfg.readEntry (objectName () + QLatin1String (" Row"), -1);
         col = cfg.readEntry (objectName () + QLatin1String (" Col"), -1);
@@ -249,7 +249,7 @@ void kpToolWidgetBase::saveSelectedAsDefault () const
         return;
     }
 
-    KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupTools);
+    KConfigGroup cfg (KSharedConfig::openConfig (), QStringLiteral(kpSettingsGroupTools));
 
     cfg.writeEntry (objectName () + QLatin1String (" Row"), m_selectedRow);
     cfg.writeEntry (objectName () + QLatin1String (" Col"), m_selectedCol);
